@@ -100,7 +100,7 @@ class SymSpell(PickleMixin):
         self._max_dictionary_edit_distance = max_dictionary_edit_distance
         self._prefix_length = prefix_length
         self._count_threshold = count_threshold
-        self._distance_algorithm = DistanceAlgorithm.DAMERUAUOSA
+        self._distance_algorithm = DistanceAlgorithm.DAMERAU_OSA_FAST
         self._max_length = 0
 
     @property
@@ -125,6 +125,19 @@ class SymSpell(PickleMixin):
         """
         return self._deletes
 
+    @property
+    def distance_algorithm(self) -> DistanceAlgorithm:
+        """The current distance algorithm."""
+        return self._distance_algorithm
+
+    @distance_algorithm.setter
+    def distance_algorithm(self, value: DistanceAlgorithm) -> None:
+        if not isinstance(value, DistanceAlgorithm):
+            raise TypeError(
+                "can only assign DistanceAlgorithm type values to distance_algorithm"
+            )
+        self._distance_algorithm = value
+
     @property
     def entry_count(self) -> int:
         """Number of unique correct spelling words."""
@@ -365,7 +378,7 @@ class SymSpell(PickleMixin):
         if max_edit_distance is None:
             max_edit_distance = self._max_dictionary_edit_distance
         if max_edit_distance > self._max_dictionary_edit_distance:
-            raise ValueError("Distance too large")
+            raise ValueError("distance too large")
         suggestions: List[SuggestItem] = []
         phrase_len = len(phrase)
 
@@ -429,16 +442,20 @@ class SymSpell(PickleMixin):
             len_diff = phrase_prefix_len - candidate_len
 
             # early termination: if candidate distance is already higher than
-            # suggestion distance, than there are no better suggestions to be
+            # suggestion distance, then there are no better suggestions to be
             # expected
             if len_diff > max_edit_distance_2:
                 # skip to next candidate if Verbosity.ALL, look no
                 # further if Verbosity.TOP or CLOSEST (candidates are
                 # ordered by delete distance, so none are closer than
                 # current)
-                if verbosity == Verbosity.ALL:
+                if verbosity == Verbosity.ALL:  # pragma: no cover
+                    # `max_edit_distance_2`` only updated when
+                    # verbosity != ALL. New candidates are generated from
+                    # deletes so it keeps getting shorter. This should never
+                    # be reached.
                     continue
-                break
+                break  # pragma: no cover, "peephole" optimization, http://bugs.python.org/issue2506
 
             if candidate in self._deletes:
                 dict_suggestions = self._deletes[candidate]
@@ -457,7 +474,7 @@ class SymSpell(PickleMixin):
                         # delete or is in same bin only because of hash collision
                         or (suggestion_len == candidate_len and suggestion != candidate)
                     ):
-                        continue
+                        continue  # pragma: no cover, "peephole" optimization, http://bugs.python.org/issue2506
                     suggestion_prefix_len = min(suggestion_len, self._prefix_length)
                     if (
                         suggestion_prefix_len > phrase_prefix_len
@@ -491,15 +508,23 @@ class SymSpell(PickleMixin):
                         ):
                             continue
                     elif suggestion_len == 1:
+                        # This should always be phrase_len - 1? Since
+                        # suggestions are generated from deletes of the input
+                        # phrase
                         distance = (
                             phrase_len
                             if phrase.index(suggestion[0]) < 0
                             else phrase_len - 1
                         )
+                        # `suggestion` only gets added to
+                        # `considered_suggestions` when `suggestion_len>1`.
+                        # Given the max_dictionary_edit_distance and
+                        # prefix_length restrictions, `distance`` should never
+                        # be >max_edit_distance_2
                         if (
                             distance > max_edit_distance_2
                             or suggestion in considered_suggestions
-                        ):
+                        ):  # pragma: no cover
                             continue
                     # number of edits in prefix ==maxeditdistance AND no
                     # identical suffix, then editdistance>max_edit_distance and
@@ -515,7 +540,7 @@ class SymSpell(PickleMixin):
                             )
                         else:
                             min_distance = 0
-                        # pylint: disable=C0301,R0916
+                        # pylint: disable=too-many-boolean-expressions
                         if (
                             self._prefix_length - max_edit_distance == candidate_len
                             and (
@@ -549,7 +574,7 @@ class SymSpell(PickleMixin):
                     # do not process higher distances than those already found,
                     # if verbosity<ALL (note: max_edit_distance_2 will always
                     # equal max_edit_distance when Verbosity.ALL)
-                    if distance <= max_edit_distance_2:
+                    if distance <= max_edit_distance_2:  # pragma: no branch
                         suggestion_count = self._words[suggestion]
                         item = SuggestItem(suggestion, distance, suggestion_count)
                         if suggestions:
@@ -559,7 +584,7 @@ class SymSpell(PickleMixin):
                                 if distance < max_edit_distance_2:
                                     suggestions = []
                             elif verbosity == Verbosity.TOP:
-                                if (
+                                if (  # pragma: no branch, "peephole" optimization, http://bugs.python.org/issue2506
                                     distance < max_edit_distance_2
                                     or suggestion_count > suggestions[0].count
                                 ):
@@ -629,7 +654,8 @@ class SymSpell(PickleMixin):
                 uppercase vs lowercase --- should be carried over from `phrase`.
             split_by_space: Splits the phrase into words simply based on space.
             ignore_any_term_with_digits: A flag to determine whether any term
-                with digits is left alone during the spell checking process.
+                with digits is left alone during the spell checking process. Only
+                works when ``ignore_non_words` is also ``True``.
 
         Returns:
             A list of :class:`SuggestItem` objects representing suggested correct
@@ -689,6 +715,7 @@ class SymSpell(PickleMixin):
                     ):
                         suggestions_combi[0].distance += 1
                         suggestion_parts[-1] = suggestions_combi[0]
+                        self._replaced_words[terms_1[i - 1]] = suggestions_combi[0]
                         is_last_combi = True
                         continue
             is_last_combi = False
